@@ -9,8 +9,8 @@ use File::Basename;
 use File::Path;
 use File::Spec;
 
-my $path
-    = abs_path( File::Spec->catdir( $RealBin, '..', '..', 'root', 'static', 'css' ) );
+my $path = abs_path(
+    File::Spec->catdir( $RealBin, '..', '..', 'root', 'static', 'css' ) );
 
 my $files = File::Next::files($path);
 
