@@ -9,7 +9,8 @@ use File::Basename;
 use File::Path;
 use File::Spec;
 
-my $path = abs_path( File::Spec->catdir( $RealBin, '..', '..', 'root', 'static' ) );
+my $path = abs_path(
+    File::Spec->catdir( $RealBin, '..', '..', 'root', 'static' ) );
 
 my $files = File::Next::files($path);
 
