@@ -16,15 +16,17 @@ open( my $fh, '>', File::Spec->catfile( $RealBin, 'critic.txt' ) );
 flock( $fh, 2 );
 
 while ( defined( my $file = $files->() ) ) {
-    next if ( $file !~ /\.(p[ml]|t)$/ );            # only .pm .pl .t
-    next if ( $file =~ /Schema\.pm$/ );             # skip this file
-    next if ( $file =~ /(\/|\\)Schema(\/|\\)/ );    # skip Schema dir and Schema.pm
-    next if ( $file =~ /Version\.pm/ );             # skip Foorum/Version.pm
+    next if ( $file !~ /\.(p[ml]|t)$/ );    # only .pm .pl .t
+    next if ( $file =~ /Schema\.pm$/ );     # skip this file
+    next
+        if ( $file =~ /(\/|\\)Schema(\/|\\)/ )
+        ;                                   # skip Schema dir and Schema.pm
+    next if ( $file =~ /Version\.pm/ );     # skip Foorum/Version.pm
 
     print "$file\n";
 
     my @violations = $critic->critique($file);
-    $file =~ s/\\/\//isg;                           # for Win32
+    $file =~ s/\\/\//isg;                   # for Win32
     $file =~ s/^$path//isg;
     unless ( scalar @violations ) {
         print $fh "$file source OK\n";
