@@ -150,6 +150,10 @@ sub forum_list : Regex('^forum/(\w+)$') {
         }
     );
 
+    # Forum Links
+    my @links = $c->model('DBIC::ForumSettings')->get_forum_links($forum_id);
+    $c->stash->{forum_links} = \@links;
+
     $c->stash->{whos_view_this_page} = 1;
     $c->stash->{pager}               = $pager;
     $c->stash->{topics}              = \@topics;
@@ -446,6 +450,8 @@ sub create : Local {
             value    => time(),
         }
     );
+    $c->model('DBIC')->resultset('ForumSettings')
+        ->clear_cache( $forum->forum_id );
 
     $c->res->redirect("/forum/$forum_code");
 }
@@ -458,8 +464,8 @@ sub about : Chained('forum') Args(0) {
     my $forum_code = $forum->{forum_code};
 
     # get all settings, so that we have created_time
-    $c->stash->{settings} = $c->model('DBIC')->resultset('Forum')
-        ->get_forum_settings( $forum, { all => 1 } );
+    $c->stash->{settings} = $c->model('DBIC')->resultset('ForumSettings')
+        ->get_all( $forum->{forum_id} );
 
     # get all moderators
     $c->stash->{forum_roles}
