@@ -22,11 +22,13 @@ __PACKAGE__->add_columns(
     data_type => "VARCHAR",
     default_value => undef,
     is_nullable => 0,
-    size => 48,
+    size => 255,
   },
 );
 __PACKAGE__->set_primary_key("forum_id", "type");
 
+__PACKAGE__->resultset_class('Foorum::ResultSet::ForumSettings');
+
 1;
 __END__
 
@@ -66,3 +68,43 @@ Fayland Lam <fayland at gmail.com>
 
 =cut
 
+
+1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::ForumSettings - Table 'forum_settings'
+
+=head1 COLUMNS
+
+=over 4
+
+=item forum_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item type
+
+VARCHAR(48)
+
+NOT NULL, PRIMARY KEY
+
+=item value
+
+VARCHAR(255)
+
+NOT NULL
+
+=back
+
+=head1 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
