@@ -24,7 +24,8 @@ sub work {
     if ( $upload_id !~ /^\d+$/ ) {
         return $job->failed("Wrong upload_id: $upload_id");
     }
-    my $upload = $schema->resultset('Upload')->find( { upload_id => $upload_id } );
+    my $upload
+        = $schema->resultset('Upload')->find( { upload_id => $upload_id } );
     unless ($upload) {
         return $job->failed("No upload for $upload_id");
     }
@@ -34,7 +35,8 @@ sub work {
     my $directory_2 = int( $upload_id / 3200 );
     my $file        = abs_path(
         File::Spec->catfile(
-            $base_path,   'root', 'upload', $directory_1,
+            $base_path,   'root',
+            'upload',     $directory_1,
             $directory_2, $upload->filename
         )
     );
